@@ -1,7 +1,7 @@
 package Media::Info;
 
-our $DATE = '2016-04-06'; # DATE
-our $VERSION = '0.10'; # VERSION
+our $DATE = '2016-06-02'; # DATE
+our $VERSION = '0.11'; # VERSION
 
 use 5.010001;
 use strict;
@@ -21,6 +21,12 @@ $SPEC{get_media_info} = {
     args => {
         media => {
             summary => 'Media file/URL',
+            description => <<'_',
+
+Note that not every backend can retrieve URL. At the time of this writing, only
+the Mplayer backend can.
+
+_
             schema  => 'str*',
             pos     => 0,
             req     => 1,
@@ -28,6 +34,15 @@ $SPEC{get_media_info} = {
         backend => {
             summary => "Choose specific backend",
             schema  => ['str*', match => '\A\w+\z'],
+            completion => sub {
+                require Complete::Module;
+
+                my %args = @_;
+                Complete::Module::complete_module(
+                    word => $args{word},
+                    ns_prefix => 'Media::Info',
+                );
+            },
         },
     },
 };
@@ -84,7 +99,7 @@ Media::Info - Return information on media file/URL
 
 =head1 VERSION
 
-This document describes version 0.10 of Media::Info (from Perl distribution Media-Info), released on 2016-04-06.
+This document describes version 0.11 of Media::Info (from Perl distribution Media-Info), released on 2016-06-02.
 
 =head1 SYNOPSIS
 
@@ -137,6 +152,9 @@ Choose specific backend.
 
 Media file/URL.
 
+Note that not every backend can retrieve URL. At the time of this writing, only
+the Mplayer backend can.
+
 =back
 
 Returns an enveloped result (an array).
